module ImportColorsFromCSV
@lines_to_skip = 1

def self.run(file=UI.openpanel("Open the CSV file") )
  begin
    model = Sketchup.active_model
    model.start_operation("Import Colors from CSV")
    file = File.expand_path(file)
    lines = IO.readlines(file)
    lines.slice!(0, @lines_to_skip) # skip first two lines
    count = 0
    lines.each{|l|
      # name;;;;;r;g;b
      l = l.split(/;|,/).delete_if{|s| s==""}
      next if l.length<4
      name = l[0].gsub(/"/,"")
      r = l[-3].strip.to_i
      g = l[-2].strip.to_i
      b = l[-1].strip.to_i
      color = Sketchup::Color.new(r, g, b)
      mat = model.materials.add(name)
      mat.color = color
      count += 1
    }
    model.commit_operation
  rescue Exception => e
    model.abort_operation
    puts("Error #<#{e.class.name}:#{e.message}.>")
    puts(e.backtrace) if $VERBOSE
    UI.messagebox("Error when importing Colors")
  else
    UI.messagebox(count.to_s + " colors imported")
  end #begin/rescue
end #def run

end #module ImportColorsFromCSV

if( not file_loaded?(File.basename(__FILE__)) )
  cmd_import_colors = UI::Command.new("Import Colors from CSV file"){ImportColorsFromCSV.run}
  UI.menu("Plugins").add_item(cmd_import_colors)
end

file_loaded(File.basename(__FILE__))
